==> images-1.1.0-20130618.124054-12-sources.jar: org/gcube/application/aquamaps/images/Report.java <==
package org.gcube.application.aquamaps.images;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.gcube.application.aquamaps.images.model.SpeciesInfo;
import org.gcube.common.core.utils.logging.GCUBELog;

import com.j256.ormlite.dao.CloseableIterator;

public class Report extends HttpServlet {
	/**
	 * 
	 */
	private static final long serialVersionUID = 2486605867155769417L;
	private static final GCUBELog logger=new GCUBELog(Report.class);
	private static DateFormat df = new  SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss");
	@Override
	protected void doGet(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException {
		CloseableIterator<SpeciesInfo> it=null;
		try{
			Common com=Common.get();
		it=com.getDao().closeableIterator();
		PrintWriter writer=resp.getWriter();
		long count=0;
		while(it.hasNext()){
			writer.println(it.next().toString());
			count++;
		}
		writer.println("Total count "+count);
		writer.println("Last completed routine "+df.format(new Date(com.getLastCompletedUpdate())));
		writer.println("Update interval in minutes "+com.getProperty(Common.FETCH_ROUTINE_INTERVAL_MINUTES));
		writer.println("GCUBE Scope "+com.getProperty(Common.SCOPE_PROP));
		writer.println("Suitable hspec id "+com.getProperty(Common.SUITABLE_PROP));
		writer.println("Suitable 2050 hspec id "+com.getProperty(Common.SUITABLE_2050_PROP));
		writer.println("Native hspec id "+com.getProperty(Common.NATIVE_PROP));
		writer.println("Native 2050 hspec id "+com.getProperty(Common.NATIVE_2050_PROP));
		writer.flush();
		}catch(Exception e){
			logger.error("Unexpected Error ",e);
			resp.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
		}finally{
			if(it!=null)try{
				it.close();
			}catch(Exception e){
				logger.fatal("Unable to close iterator ",e);
			}			
		}
	}
}

==> images-1.2.0-20140330.234551-137-sources.jar: org/gcube/application/aquamaps/images/Report.java <==
package org.gcube.application.aquamaps.images;

import java.io.IOException;
import java.io.PrintWriter;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.gcube.application.aquamaps.images.model.SpeciesInfo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.j256.ormlite.dao.CloseableIterator;

public class Report extends HttpServlet {
	/**
	 * 
	 */
	private static final long serialVersionUID = 2486605867155769417L;
	private static final Logger logger = LoggerFactory.getLogger(Report.class);
	private static DateFormat df = new  SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss");
	@Override
	protected void doGet(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException {
		CloseableIterator<SpeciesInfo> it=null;
		try{
			Common com=Common.get();
		it=com.getDao().closeableIterator();
		PrintWriter writer=resp.getWriter();
		long count=0;
		while(it.hasNext()){
			writer.println(it.next().toString());
			count++;
		}
		writer.println("Total count "+count);
		writer.println("Last completed routine "+df.format(new Date(com.getLastCompletedUpdate())));

		writer.println("Last used configuration");
		Map<String,String> lastConfiguration=com.getLastConfiguration();
		writer.println("Update interval in minutes "+lastConfiguration.get(Common.FETCH_ROUTINE_INTERVAL_MINUTES));
		writer.println("GCUBE Scope "+lastConfiguration.get(Common.SCOPE_PROP));
		writer.println("Suitable hspec id "+lastConfiguration.get(Common.SUITABLE_PROP));
		writer.println("Suitable 2050 hspec id "+lastConfiguration.get(Common.SUITABLE_2050_PROP));
		writer.println("Native hspec id "+lastConfiguration.get(Common.NATIVE_PROP));
		writer.println("Native 2050 hspec id "+lastConfiguration.get(Common.NATIVE_2050_PROP));
		
		writer.println("Current configuration");
		writer.println("Update interval in minutes "+com.getProperty(Common.FETCH_ROUTINE_INTERVAL_MINUTES));
		writer.println("GCUBE Scope "+com.getProperty(Common.SCOPE_PROP));
		writer.println("Suitable hspec id "+com.getProperty(Common.SUITABLE_PROP));
		writer.println("Suitable 2050 hspec id "+com.getProperty(Common.SUITABLE_2050_PROP));
		writer.println("Native hspec id "+com.getProperty(Common.NATIVE_PROP));
		writer.println("Native 2050 hspec id "+com.getProperty(Common.NATIVE_2050_PROP));
		writer.flush();
		}catch(Exception e){
			logger.error("Unexpected Error ",e);
			resp.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
		}finally{
			if(it!=null)try{
				it.close();
			}catch(Exception e){
				logger.error("Unable to close iterator ",e);
			}			
		}
	}
}
